//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yakus](index.md)/[getYaku](get-yaku.md)

# getYaku

[common]\
fun [getYaku](get-yaku.md)(name: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)): [Yaku](../-yaku/index.md)

根据役种名获取役种

#### Return

役种

#### Parameters

common

| | |
|---|---|
| name | 役种名 |
